@@ -24,8 +24,8 @@ func TestApplier_ApplyLayers(t *testing.T) {
 	tests := []struct {
 		name                 string
 		args                 args
-		getLayerExpectations []cache.CacheGetBlobExpectation
-		getImageExpectations []cache.CacheGetArtifactExpectation
+		getLayerExpectations []cache.LocalArtifactCacheGetBlobExpectation
+		getImageExpectations []cache.LocalArtifactCacheGetArtifactExpectation
 		want                 types.ArtifactDetail
 		wantErr              string
 	}{
@@ -39,17 +39,17 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					"sha256:24df0d4e20c0f42d3703bf1f1db2bdd77346c7956f74f423603d651e8e5ae8a7",
 				},
 			},
-			getLayerExpectations: []cache.CacheGetBlobExpectation{
+			getLayerExpectations: []cache.LocalArtifactCacheGetBlobExpectation{
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
 					},
-					Returns: cache.CacheGetBlobReturns{
+					Returns: cache.LocalArtifactCacheGetBlobReturns{
 						BlobInfo: types.BlobInfo{
 							SchemaVersion: 1,
 							Digest:        "sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
 							DiffID:        "sha256:a187dde48cd289ac374ad8539930628314bc581a481cdb41409c9289419ddb72",
-							OS: &types.OS{
+							OS: types.OS{
 								Family: "debian",
 								Name:   "9.9",
 							},
@@ -70,10 +70,10 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					},
 				},
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:dffd9992ca398466a663c87c92cfea2a2db0ae0cf33fcb99da60eec52addbfc5",
 					},
-					Returns: cache.CacheGetBlobReturns{
+					Returns: cache.LocalArtifactCacheGetBlobReturns{
 						BlobInfo: types.BlobInfo{
 							SchemaVersion: 1,
 							Digest:        "sha256:dffd9992ca398466a663c87c92cfea2a2db0ae0cf33fcb99da60eec52addbfc5",
@@ -98,10 +98,10 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					},
 				},
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:24df0d4e20c0f42d3703bf1f1db2bdd77346c7956f74f423603d651e8e5ae8a7",
 					},
-					Returns: cache.CacheGetBlobReturns{
+					Returns: cache.LocalArtifactCacheGetBlobReturns{
 						BlobInfo: types.BlobInfo{
 							SchemaVersion: 1,
 							Digest:        "sha256:beee9f30bc1f711043e78d4a2be0668955d4b761d587d6f60c2c8dc081efb203",
@@ -126,12 +126,12 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					},
 				},
 			},
-			getImageExpectations: []cache.CacheGetArtifactExpectation{
+			getImageExpectations: []cache.LocalArtifactCacheGetArtifactExpectation{
 				{
-					Args: cache.CacheGetArtifactArgs{
+					Args: cache.LocalArtifactCacheGetArtifactArgs{
 						ArtifactID: "sha256:4791503518dff090d6a82f7a5c1fd71c41146920e2562fb64308e17ab6834b7e",
 					},
-					Returns: cache.CacheGetArtifactReturns{
+					Returns: cache.LocalArtifactCacheGetArtifactReturns{
 						ArtifactInfo: types.ArtifactInfo{
 							SchemaVersion: 1,
 						},
@@ -139,7 +139,7 @@ func TestApplier_ApplyLayers(t *testing.T) {
 				},
 			},
 			want: types.ArtifactDetail{
-				OS: &types.OS{
+				OS: types.OS{
 					Family: "debian",
 					Name:   "9.9",
 				},
@@ -193,17 +193,17 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					"sha256:531743b7098cb2aaf615641007a129173f63ed86ca32fe7b5a246a1c47286028",
 				},
 			},
-			getLayerExpectations: []cache.CacheGetBlobExpectation{
+			getLayerExpectations: []cache.LocalArtifactCacheGetBlobExpectation{
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:531743b7098cb2aaf615641007a129173f63ed86ca32fe7b5a246a1c47286028",
 					},
-					Returns: cache.CacheGetBlobReturns{
+					Returns: cache.LocalArtifactCacheGetBlobReturns{
 						BlobInfo: types.BlobInfo{
 							SchemaVersion: 1,
 							Digest:        "sha256:a187dde48cd289ac374ad8539930628314bc581a481cdb41409c9289419ddb72",
 							DiffID:        "sha256:531743b7098cb2aaf615641007a129173f63ed86ca32fe7b5a246a1c47286028",
-							OS: &types.OS{
+							OS: types.OS{
 								Family: "alpine",
 								Name:   "3.10.4",
 							},
@@ -223,12 +223,12 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					},
 				},
 			},
-			getImageExpectations: []cache.CacheGetArtifactExpectation{
+			getImageExpectations: []cache.LocalArtifactCacheGetArtifactExpectation{
 				{
-					Args: cache.CacheGetArtifactArgs{
+					Args: cache.LocalArtifactCacheGetArtifactArgs{
 						ArtifactID: "sha256:3bb70bd5fb37e05b8ecaaace5d6a6b5ec7834037c07ecb5907355c23ab70352d",
 					},
-					Returns: cache.CacheGetArtifactReturns{
+					Returns: cache.LocalArtifactCacheGetArtifactReturns{
 						ArtifactInfo: types.ArtifactInfo{
 							SchemaVersion: 1,
 							HistoryPackages: []types.Package{
@@ -246,7 +246,7 @@ func TestApplier_ApplyLayers(t *testing.T) {
 				},
 			},
 			want: types.ArtifactDetail{
-				OS: &types.OS{
+				OS: types.OS{
 					Family: "alpine",
 					Name:   "3.10.4",
 				},
@@ -311,12 +311,12 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					"sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
 				},
 			},
-			getLayerExpectations: []cache.CacheGetBlobExpectation{
+			getLayerExpectations: []cache.LocalArtifactCacheGetBlobExpectation{
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
 					},
-					Returns: cache.CacheGetBlobReturns{BlobInfo: types.BlobInfo{}},
+					Returns: cache.LocalArtifactCacheGetBlobReturns{BlobInfo: types.BlobInfo{}},
 				},
 			},
 			wantErr: "layer cache missing",
@@ -328,12 +328,12 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					"sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
 				},
 			},
-			getLayerExpectations: []cache.CacheGetBlobExpectation{
+			getLayerExpectations: []cache.LocalArtifactCacheGetBlobExpectation{
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
 					},
-					Returns: cache.CacheGetBlobReturns{BlobInfo: types.BlobInfo{}},
+					Returns: cache.LocalArtifactCacheGetBlobReturns{BlobInfo: types.BlobInfo{}},
 				},
 			},
 			wantErr: "layer cache missing",
@@ -348,12 +348,12 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					"sha256:24df0d4e20c0f42d3703bf1f1db2bdd77346c7956f74f423603d651e8e5ae8a7",
 				},
 			},
-			getLayerExpectations: []cache.CacheGetBlobExpectation{
+			getLayerExpectations: []cache.LocalArtifactCacheGetBlobExpectation{
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
 					},
-					Returns: cache.CacheGetBlobReturns{
+					Returns: cache.LocalArtifactCacheGetBlobReturns{
 						BlobInfo: types.BlobInfo{
 							SchemaVersion: 1,
 							Digest:        "sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
@@ -375,10 +375,10 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					},
 				},
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:dffd9992ca398466a663c87c92cfea2a2db0ae0cf33fcb99da60eec52addbfc5",
 					},
-					Returns: cache.CacheGetBlobReturns{
+					Returns: cache.LocalArtifactCacheGetBlobReturns{
 						BlobInfo: types.BlobInfo{
 							SchemaVersion: 1,
 							Digest:        "sha256:dffd9992ca398466a663c87c92cfea2a2db0ae0cf33fcb99da60eec52addbfc5",
@@ -403,10 +403,10 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					},
 				},
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:24df0d4e20c0f42d3703bf1f1db2bdd77346c7956f74f423603d651e8e5ae8a7",
 					},
-					Returns: cache.CacheGetBlobReturns{
+					Returns: cache.LocalArtifactCacheGetBlobReturns{
 						BlobInfo: types.BlobInfo{
 							SchemaVersion: 1,
 							Digest:        "sha256:beee9f30bc1f711043e78d4a2be0668955d4b761d587d6f60c2c8dc081efb203",
@@ -482,15 +482,15 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					"sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
 				},
 			},
-			getLayerExpectations: []cache.CacheGetBlobExpectation{
+			getLayerExpectations: []cache.LocalArtifactCacheGetBlobExpectation{
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
 					},
-					Returns: cache.CacheGetBlobReturns{
+					Returns: cache.LocalArtifactCacheGetBlobReturns{
 						BlobInfo: types.BlobInfo{
 							SchemaVersion: 1,
-							OS: &types.OS{
+							OS: types.OS{
 								Family: "debian",
 								Name:   "9.9",
 							},
@@ -499,7 +499,7 @@ func TestApplier_ApplyLayers(t *testing.T) {
 				},
 			},
 			want: types.ArtifactDetail{
-				OS: &types.OS{
+				OS: types.OS{
 					Family: "debian",
 					Name:   "9.9",
 				},
@@ -515,12 +515,12 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					"sha256:dffd9992ca398466a663c87c92cfea2a2db0ae0cf33fcb99da60eec52addbfc5",
 				},
 			},
-			getLayerExpectations: []cache.CacheGetBlobExpectation{
+			getLayerExpectations: []cache.LocalArtifactCacheGetBlobExpectation{
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
 					},
-					Returns: cache.CacheGetBlobReturns{
+					Returns: cache.LocalArtifactCacheGetBlobReturns{
 						BlobInfo: types.BlobInfo{
 							SchemaVersion: 1,
 							Digest:        "sha256:932da51564135c98a49a34a193d6cd363d8fa4184d957fde16c9d8527b3f3b02",
@@ -558,10 +558,10 @@ func TestApplier_ApplyLayers(t *testing.T) {
 					},
 				},
 				{
-					Args: cache.CacheGetBlobArgs{
+					Args: cache.LocalArtifactCacheGetBlobArgs{
 						BlobID: "sha256:dffd9992ca398466a663c87c92cfea2a2db0ae0cf33fcb99da60eec52addbfc5",
 					},
-					Returns: cache.CacheGetBlobReturns{
+					Returns: cache.LocalArtifactCacheGetBlobReturns{
 						BlobInfo: types.BlobInfo{
 							SchemaVersion: 1,
 							Digest:        "sha256:dffd9992ca398466a663c87c92cfea2a2db0ae0cf33fcb99da60eec52addbfc5",
@@ -677,7 +677,7 @@ func TestApplier_ApplyLayers(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			c := new(cache.MockCache)
+			c := new(cache.MockLocalArtifactCache)
 			c.ApplyGetBlobExpectations(tt.getLayerExpectations)
 			c.ApplyGetArtifactExpectations(tt.getImageExpectations)
 
@@ -691,9 +691,7 @@ func TestApplier_ApplyLayers(t *testing.T) {
 				require.NoError(t, err, tt.name)
 			}
 
-			sort.Slice(got.Packages, func(i, j int) bool {
-				return got.Packages[i].Name < got.Packages[j].Name
-			})
+			sort.Sort(got.Packages)
 			for _, app := range got.Applications {
 				sort.Slice(app.Libraries, func(i, j int) bool {
 					return app.Libraries[i].Name < app.Libraries[j].Name
