@@ -4,12 +4,50 @@ import (
 	"time"
 
 	v1 "github.com/google/go-containerregistry/pkg/v1"
+	"github.com/samber/lo"
+
+	aos "github.com/aquasecurity/trivy/pkg/fanal/analyzer/os"
 )
 
 type OS struct {
 	Family string
 	Name   string
 	Eosl   bool `json:"EOSL,omitempty"`
+
+	// This field is used for enhanced security maintenance programs such as Ubuntu ESM, Debian Extended LTS.
+	Extended bool `json:"extended,omitempty"`
+}
+
+func (o *OS) Detected() bool {
+	return o.Family != ""
+}
+
+// Merge merges OS version and enhanced security maintenance programs
+func (o *OS) Merge(new OS) {
+	if lo.IsEmpty(new) {
+		return
+	}
+
+	switch {
+	// OLE also has /etc/redhat-release and it detects OLE as RHEL by mistake.
+	// In that case, OS must be overwritten with the content of /etc/oracle-release.
+	// There is the same problem between Debian and Ubuntu.
+	case o.Family == aos.RedHat, o.Family == aos.Debian:
+		*o = new
+	default:
+		if o.Family == "" {
+			o.Family = new.Family
+		}
+		if o.Name == "" {
+			o.Name = new.Name
+		}
+		// Ubuntu has ESM program: https://ubuntu.com/security/esm
+		// OS version and esm status are stored in different files.
+		// We have to merge OS version after parsing these files.
+		if o.Extended || new.Extended {
+			o.Extended = true
+		}
+	}
 }
 
 type Repository struct {
@@ -72,6 +110,26 @@ func (pkg *Package) Empty() bool {
 	return pkg.Name == "" || pkg.Version == ""
 }
 
+type Packages []Package
+
+func (pkgs Packages) Len() int {
+	return len(pkgs)
+}
+
+func (pkgs Packages) Swap(i, j int) {
+	pkgs[i], pkgs[j] = pkgs[j], pkgs[i]
+}
+
+func (pkgs Packages) Less(i, j int) bool {
+	switch {
+	case pkgs[i].Name != pkgs[j].Name:
+		return pkgs[i].Name < pkgs[j].Name
+	case pkgs[i].Version != pkgs[j].Version:
+		return pkgs[i].Version < pkgs[j].Version
+	}
+	return pkgs[i].FilePath < pkgs[j].FilePath
+}
+
 type SrcPackage struct {
 	Name        string   `json:"name"`
 	Version     string   `json:"version"`
@@ -80,7 +138,7 @@ type SrcPackage struct {
 
 type PackageInfo struct {
 	FilePath string
-	Packages []Package
+	Packages Packages
 }
 
 type Application struct {
@@ -157,7 +215,7 @@ type BlobInfo struct {
 	WhiteoutFiles []string `json:",omitempty"`
 
 	// Analysis result
-	OS                *OS                `json:",omitempty"`
+	OS                OS                 `json:",omitempty"`
 	Repository        *Repository        `json:",omitempty"`
 	PackageInfos      []PackageInfo      `json:",omitempty"`
 	Applications      []Application      `json:",omitempty"`
@@ -175,30 +233,11 @@ type BlobInfo struct {
 	CustomResources []CustomResource `json:",omitempty"`
 }
 
-// ToArtifactDetail is used to restore the merged layer from cache.
-func (b *BlobInfo) ToArtifactDetail() ArtifactDetail {
-	var pkgs []Package
-	// The size must be 1 as this BlobInfo contains the merged layer.
-	if len(b.PackageInfos) == 1 {
-		pkgs = b.PackageInfos[0].Packages
-	}
-	return ArtifactDetail{
-		OS:                b.OS,
-		Repository:        b.Repository,
-		Packages:          pkgs,
-		Applications:      b.Applications,
-		Misconfigurations: b.Misconfigurations,
-		Secrets:           b.Secrets,
-		Licenses:          b.Licenses,
-		CustomResources:   b.CustomResources,
-	}
-}
-
 // ArtifactDetail is generated by applying blobs
 type ArtifactDetail struct {
-	OS                *OS                `json:",omitempty"`
+	OS                OS                 `json:",omitempty"`
 	Repository        *Repository        `json:",omitempty"`
-	Packages          []Package          `json:",omitempty"`
+	Packages          Packages           `json:",omitempty"`
 	Applications      []Application      `json:",omitempty"`
 	Misconfigurations []Misconfiguration `json:",omitempty"`
 	Secrets           []Secret           `json:",omitempty"`
