@@ -4,6 +4,7 @@ import (
 	"context"
 	"os"
 	"path/filepath"
+	"runtime"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
@@ -16,6 +17,10 @@ import (
 )
 
 func TestManager_Register(t *testing.T) {
+	if runtime.GOOS == "windows" {
+		// WASM tests difficult on Windows
+		t.Skip("Test satisfied adequately by Linux tests")
+	}
 	tests := []struct {
 		name                    string
 		noModuleDir             bool
@@ -92,7 +97,10 @@ func TestManager_Register(t *testing.T) {
 			}()
 
 			// Confirm the analyzer is registered
-			got := analyzer.NewAnalyzerGroup("", nil).AnalyzerVersions()
+			a, err := analyzer.NewAnalyzerGroup(analyzer.AnalyzerOptions{})
+			require.NoError(t, err)
+
+			got := a.AnalyzerVersions()
 			assert.Equal(t, tt.wantAnalyzerVersions, got)
 
 			// Confirm the post scanner is registered
