@@ -7,8 +7,7 @@ import (
 	"github.com/google/wire"
 	"golang.org/x/xerrors"
 
-	"github.com/aquasecurity/fanal/cache"
-	"github.com/aquasecurity/trivy/pkg/result"
+	"github.com/aquasecurity/trivy/pkg/fanal/cache"
 	"github.com/aquasecurity/trivy/pkg/rpc"
 	"github.com/aquasecurity/trivy/pkg/scanner"
 	"github.com/aquasecurity/trivy/pkg/scanner/local"
@@ -21,36 +20,31 @@ import (
 var ScanSuperSet = wire.NewSet(
 	local.SuperSet,
 	wire.Bind(new(scanner.Driver), new(local.Scanner)),
-	result.SuperSet,
 	NewScanServer,
 )
 
 // ScanServer implements the scanner
 type ScanServer struct {
 	localScanner scanner.Driver
-	resultClient result.Client
 }
 
 // NewScanServer is the factory method for scanner
-func NewScanServer(s scanner.Driver, vulnClient result.Client) *ScanServer {
-	return &ScanServer{localScanner: s, resultClient: vulnClient}
+func NewScanServer(s scanner.Driver) *ScanServer {
+	return &ScanServer{localScanner: s}
 }
 
 // Scan scans and return response
-func (s *ScanServer) Scan(_ context.Context, in *rpcScanner.ScanRequest) (*rpcScanner.ScanResponse, error) {
+func (s *ScanServer) Scan(ctx context.Context, in *rpcScanner.ScanRequest) (*rpcScanner.ScanResponse, error) {
 	options := types.ScanOptions{
 		VulnType:        in.Options.VulnType,
 		SecurityChecks:  in.Options.SecurityChecks,
 		ListAllPackages: in.Options.ListAllPackages,
 	}
-	results, os, err := s.localScanner.Scan(in.Target, in.ArtifactId, in.BlobIds, options)
+	results, os, err := s.localScanner.Scan(ctx, in.Target, in.ArtifactId, in.BlobIds, options)
 	if err != nil {
 		return nil, xerrors.Errorf("failed scan, %s: %w", in.Target, err)
 	}
 
-	for i := range results {
-		s.resultClient.FillVulnerabilityInfo(results[i].Vulnerabilities, results[i].Type)
-	}
 	return rpc.ConvertToRPCScanResponse(results, os), nil
 }
 
@@ -59,7 +53,7 @@ type CacheServer struct {
 	cache cache.Cache
 }
 
-// NewCacheServer is the facotry method for cacheServer
+// NewCacheServer is the factory method for cacheServer
 func NewCacheServer(c cache.Cache) *CacheServer {
 	return &CacheServer{cache: c}
 }
