@@ -40,7 +40,6 @@ var (
 // SuperSet binds dependencies for Local scan
 var SuperSet = wire.NewSet(
 	vulnerability.SuperSet,
-	wire.Value([]applier.Option(nil)), // functional options
 	applier.NewApplier,
 	wire.Bind(new(Applier), new(applier.Applier)),
 	wire.Struct(new(ospkgDetector.Detector)),
@@ -75,7 +74,7 @@ func NewScanner(applier Applier, ospkgDetector OspkgDetector, vulnClient vulnera
 }
 
 // Scan scans the artifact and return results.
-func (s Scanner) Scan(ctx context.Context, target, artifactKey string, blobKeys []string, options types.ScanOptions) (types.Results, *ftypes.OS, error) {
+func (s Scanner) Scan(ctx context.Context, target, artifactKey string, blobKeys []string, options types.ScanOptions) (types.Results, ftypes.OS, error) {
 	artifactDetail, err := s.applier.ApplyLayers(artifactKey, blobKeys)
 	switch {
 	case errors.Is(err, analyzer.ErrUnknownOS):
@@ -83,14 +82,14 @@ func (s Scanner) Scan(ctx context.Context, target, artifactKey string, blobKeys
 
 		// Packages may contain OS-independent binary information even though OS is not detected.
 		if len(artifactDetail.Packages) != 0 {
-			artifactDetail.OS = &ftypes.OS{Family: "none"}
+			artifactDetail.OS = ftypes.OS{Family: "none"}
 		}
 
 		// If OS is not detected and repositories are detected, we'll try to use repositories as OS.
 		if artifactDetail.Repository != nil {
 			log.Logger.Debugf("Package repository: %s %s", artifactDetail.Repository.Family, artifactDetail.Repository.Release)
 			log.Logger.Debugf("Assuming OS is %s %s.", artifactDetail.Repository.Family, artifactDetail.Repository.Release)
-			artifactDetail.OS = &ftypes.OS{
+			artifactDetail.OS = ftypes.OS{
 				Family: artifactDetail.Repository.Family,
 				Name:   artifactDetail.Repository.Release,
 			}
@@ -99,7 +98,7 @@ func (s Scanner) Scan(ctx context.Context, target, artifactKey string, blobKeys
 		log.Logger.Warn("No OS package is detected. Make sure you haven't deleted any files that contain information about the installed packages.")
 		log.Logger.Warn(`e.g. files under "/lib/apk/db/", "/var/lib/dpkg/" and "/var/lib/rpm"`)
 	case err != nil:
-		return nil, nil, xerrors.Errorf("failed to apply layers: %w", err)
+		return nil, ftypes.OS{}, xerrors.Errorf("failed to apply layers: %w", err)
 	}
 
 	var eosl bool
@@ -118,11 +117,10 @@ func (s Scanner) Scan(ctx context.Context, target, artifactKey string, blobKeys
 		var vulnResults types.Results
 		vulnResults, eosl, err = s.scanVulnerabilities(target, artifactDetail, options)
 		if err != nil {
-			return nil, nil, xerrors.Errorf("failed to detect vulnerabilities: %w", err)
-		}
-		if artifactDetail.OS != nil {
-			artifactDetail.OS.Eosl = eosl
+			return nil, ftypes.OS{}, xerrors.Errorf("failed to detect vulnerabilities: %w", err)
 		}
+		artifactDetail.OS.Eosl = eosl
+
 		// Merge package results into vulnerability results
 		mergedResults := s.fillPkgsInVulns(pkgResults, vulnResults)
 
@@ -166,14 +164,14 @@ func (s Scanner) Scan(ctx context.Context, target, artifactKey string, blobKeys
 	// Post scanning
 	results, err = post.Scan(ctx, results)
 	if err != nil {
-		return nil, nil, xerrors.Errorf("post scan error: %w", err)
+		return nil, ftypes.OS{}, xerrors.Errorf("post scan error: %w", err)
 	}
 
 	return results, artifactDetail.OS, nil
 }
 
 func (s Scanner) osPkgsToResult(target string, detail ftypes.ArtifactDetail, options types.ScanOptions) *types.Result {
-	if len(detail.Packages) == 0 || detail.OS == nil {
+	if len(detail.Packages) == 0 || !detail.OS.Detected() {
 		return nil
 	}
 
@@ -181,9 +179,7 @@ func (s Scanner) osPkgsToResult(target string, detail ftypes.ArtifactDetail, opt
 	if options.ScanRemovedPackages {
 		pkgs = mergePkgs(pkgs, detail.HistoryPackages)
 	}
-	sort.Slice(pkgs, func(i, j int) bool {
-		return strings.Compare(pkgs[i].Name, pkgs[j].Name) <= 0
-	})
+	sort.Sort(pkgs)
 	return &types.Result{
 		Target:   fmt.Sprintf("%s (%s %s)", target, detail.OS.Family, detail.OS.Name),
 		Class:    types.ClassOSPkg,
@@ -242,7 +238,7 @@ func (s Scanner) scanVulnerabilities(target string, detail ftypes.ArtifactDetail
 
 func (s Scanner) scanOSPkgs(target string, detail ftypes.ArtifactDetail, options types.ScanOptions) (
 	*types.Result, bool, error) {
-	if detail.OS == nil || detail.OS.Family == "" {
+	if !detail.OS.Detected() {
 		log.Logger.Debug("Detected OS: unknown")
 		return nil, false, nil
 	}
@@ -253,6 +249,11 @@ func (s Scanner) scanOSPkgs(target string, detail ftypes.ArtifactDetail, options
 		pkgs = mergePkgs(pkgs, detail.HistoryPackages)
 	}
 
+	if detail.OS.Extended {
+		// TODO: move the logic to each detector
+		detail.OS.Name += "-ESM"
+	}
+
 	vulns, eosl, err := s.ospkgDetector.Detect("", detail.OS.Family, detail.OS.Name, detail.Repository, time.Time{}, pkgs)
 	if err == ospkgDetector.ErrUnsupportedOS {
 		return nil, false, nil
